==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.get_uq = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "uq", {
        get: function () {
            return this.get_uq();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_uh = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };

==> igniteui-react-charts-16.16.3.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.get_u3 = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "u3", {
        get: function () {
            return this.get_u3();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_uu = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };
